package com.perfectech.tis.activities;

import android.app.AlertDialog;
import android.content.ContentValues;
import android.content.Context;
import android.content.DialogInterface;
import android.content.Intent;
import android.content.SharedPreferences;
import android.graphics.Color;
import android.provider.Settings;
import android.os.Bundle;
import android.support.v7.app.AppCompatActivity;
import android.util.Log;
import android.view.Gravity;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.WindowManager;
import android.view.inputmethod.InputMethodManager;
import android.widget.ArrayAdapter;
import android.widget.EditText;
import android.widget.ScrollView;
import android.widget.Spinner;
import android.widget.TableLayout;
import android.widget.TableRow;
import android.widget.TextView;

import com.perfectech.tis.DBLogs;
import com.perfectech.tis.DateConvertClass;
import com.perfectech.tis.R;
import com.perfectech.tis.syncClasses.SyncTasks;
import com.perfectech.tis.TISDBHelper;

import java.io.IOException;
import java.util.ArrayList;

/*
This activity is pretty busy.  A new DVIR can be started and a partial completed DVIR can be
completed.  The way we will know if this is a new DVIR is if the sUniqueDVRID is not populated
when we go to save the DVIR. If this is a partial DVIR that is being completed then the
sUniqueDVIRID value will have something in it when save is pressed.
 */
public class DVIREntryActivity extends AppCompatActivity {

    private static final String sDBName = "TIS.db";
    private static final int iVersionVal = 7;
    private static String sAndroidID = "";
    private static String sUserID = "";
    private static String sUniqueDVIRID = "";
    private static ArrayList<ArrayList<String>> fieldsArrayList;
    //Need to use this on orientation changes
    private static ArrayList<String> sSpinnerFieldList;
    EditText etTruckNo;
    EditText etTrailerNo;
    EditText etBeginMiles;
    EditText etLocation;
    EditText etRemarks;
    ScrollView svCheckItems;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        setContentView(R.layout.activity_dvirentry);
        //this.setRequestedOrientation(ActivityInfo.SCREEN_ORIENTATION_PORTRAIT);
        SharedPreferences prefs = getSharedPreferences("TISSharedPrefs",
                Context.MODE_PRIVATE);
        SharedPreferences.Editor editor = prefs.edit();
        String sLoggedInUserCompany = prefs.getString("LoggedInUserCompany", "No Value");
        sUserID = prefs.getString("UserID", "No Value");
        TextView otvUserName = (TextView) findViewById(R.id.tvUserName);
        otvUserName.setText(sLoggedInUserCompany.substring(0, sLoggedInUserCompany.indexOf('-')));
        sAndroidID = Settings.System.getString(getContentResolver(),
                Settings.System.ANDROID_ID);
        etTruckNo = (EditText) findViewById(R.id.etTruckNo);
        etTrailerNo = (EditText) findViewById(R.id.etTrailerNo);
        etBeginMiles = (EditText) findViewById(R.id.etBeginOdometer);
        etLocation = (EditText) findViewById(R.id.etLocation);
        etRemarks = (EditText) findViewById(R.id.etRemarks);

        String sCurrentVersion = prefs.getString("TISVersion", "No Value");
        TextView otvCopyright = (TextView) findViewById(R.id.tvCopyright);
        String sVersionText = otvCopyright.getText().toString();
        // need to replace the %RELNUM% with the actual rel version
        sVersionText = sVersionText.replace("RELNUM", sCurrentVersion);
        otvCopyright.setText(sVersionText);

        svCheckItems = (ScrollView) findViewById(R.id.svDVIRNewCheckItems);
        if (savedInstanceState == null) {
            if (checkForPartialDVIR()) {
                //Need to populate items that are in the database
                build_partial_form();
            } else {
                // Build the checklist form that will be uses. Make sure to pass along the form number
                //Only do this if there is not a partial DVIR out there already
                Bundle extras = getIntent().getExtras();
                if (extras != null) {
                    try {
                        Integer iDVIRFormNum = extras.getInt("CheckListNumber");
                        //Integer iCheckListNumber = Integer.parseInt(sCheckListNumber);
                        build_form(iDVIRFormNum);
                        //Focus on truck number and force keyboard open only if new dvir
                        etTruckNo.requestFocus();
                        getWindow().setSoftInputMode(WindowManager.LayoutParams.SOFT_INPUT_STATE_VISIBLE);
                    } catch (Exception ex) {
                        //To do
                    }
                }
            }
        }

        //This will force close the keyboard as long as you click the left of table
        final TableLayout tlCheckItems = (TableLayout) findViewById(R.id.tlCheckItems);
        tlCheckItems.setOnClickListener(new View.OnClickListener() {
            public void onClick(View v) {
                ((InputMethodManager) getSystemService(Context.INPUT_METHOD_SERVICE)).
                        hideSoftInputFromWindow(tlCheckItems.getWindowToken(), 0);
            }
        });
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_dvir, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_save) {
            if (saveItems("FULL")) {
                queueForSync();
                Intent i = new Intent(getApplicationContext(), DVIRActivity.class);
                startActivity(i);
            } else {
                //Put up a dialogue box
                String sTitle = getResources().getString(R.string.dvir_not_complete_error_title);
                String sText = getResources().getString(R.string.dvir_save_partial_error_text);
                errorDialogue(sTitle, sText);
                return true;
            }
        }
        if (id == R.id.action_cancel) {
            Intent i = new Intent(getApplicationContext(), DVIRActivity.class);
            startActivity(i);
            finish();
            return true;
        }
        if (id == R.id.action_save_part) {
            if (saveItems("PART")) {
                Intent i = new Intent(getApplicationContext(), DVIRActivity.class);
                startActivity(i);
                finish();
            } else {
                //Put up a dialogue box
                String sTitle = getResources().getString(R.string.dvir_not_complete_error_title);
                String sText = getResources().getString(R.string.dvir_not_complete_error_text);
                errorDialogue(sTitle, sText);
            }
            return true;
        }
        if (id == R.id.action_icon_meanings) {
            Intent i = new Intent(getApplicationContext(), HelpActivity.class);
            i.putExtra("ScreenID", "IconMeanings");
            startActivity(i);
            return true;
        }
        if (id == R.id.action_help) {
            Intent i = new Intent(getApplicationContext(), HelpActivity.class);
            i.putExtra("ScreenID", "DVIREntryActivity");
            startActivity(i);
            return true;
        }
        if (id == R.id.action_about) {
            Intent i = new Intent(getApplicationContext(), AboutActivity.class);
            startActivity(i);
            return true;
        }
        return super.onOptionsItemSelected(item);
    }

    //Save the values for the spinners on orientation change
    @Override
    protected void onSaveInstanceState(Bundle outState) {
        saveState(outState);
        super.onSaveInstanceState(outState);
        //outState.putString(KEY_TEXT_VALUE, mTextView.getText());
    }

    @Override
    protected void onRestoreInstanceState(Bundle inState) {
        restoreState(inState);
    }

    /* We will build the checklist form that will be used.  This form will be dynamically built
       because we do not know initially how many items there will be
     */
    private void build_form(Integer iFormNumber) {
        try {
            TISDBHelper oDB = new TISDBHelper(getApplicationContext(), sDBName,
                    null, iVersionVal);
            try {
                oDB.createDataBase();
            } catch (IOException ioe) {
                DBLogs.insert("Error: " + ioe.toString(),
                        "DVIREntryActivity.build_form", getApplicationContext(),
                        sDBName, iVersionVal);
                throw new Error("Unable to create database");
            }

            oDB.openDataBase();

            String sSQL = "select DVIRFields._id, DVIRFields.Title from DVIRFields, DVIRAssignedFields ";
            sSQL += "where DVIRAssignedFields.FieldID = DVIRFields._id and DVIRAssignedFields.DVIRNo ='";
            sSQL += iFormNumber + "' order by DVIRAssignedFields.sortOrder, DVIRAssignedFields.FieldID";
            fieldsArrayList = oDB.selectRecordsFromDBList(sSQL, null);

            String sSQLSpinner = "select Name from DVIRCodes order by sort_order, name";
            sSpinnerFieldList = oDB.getList(sSQLSpinner, null);
            sSpinnerFieldList.add(0, "Not Checked");

            oDB.close();

            svCheckItems.setScrollbarFadingEnabled(false);
            TableLayout tlCheckListItems = (TableLayout) findViewById(R.id.tlCheckItems);

            //Make sure we have values
            if (fieldsArrayList.size() > 5) {
                for (ArrayList<String> sValue : fieldsArrayList) {
                    final TableRow trCheckItem = new TableRow(this);
                    View v = LayoutInflater.from(this).inflate(R.layout.dvir_check_table_row, trCheckItem, false);
                    TextView tvItem = (TextView) v.findViewById(R.id.tvCheckItem);
                    tvItem.setText(sValue.get(1));
                    Spinner spItem = (Spinner) v.findViewById(R.id.spCheckItem);
                    ArrayAdapter<String> spinnerArrayAdapter =
                            new ArrayAdapter<String>(this, R.layout.dvir_spinner_item, sSpinnerFieldList);
                    spinnerArrayAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
                    spItem.setAdapter(spinnerArrayAdapter);
                    tlCheckListItems.addView(v);
                }
            } else {
                //We did not have any values so do a popup
                String sTitle = getResources().getString(R.string.dvir_unexpected_error_title);
                String sText = getResources().getString(R.string.dvir_unexpected_error_text);
                errorDialogue(sTitle, sText);
            }
        } catch (Exception ex) {
            DBLogs.insert("Error: " + ex.toString(),
                    "DVIREntryActivity.build_form", getApplicationContext(),
                    sDBName, iVersionVal);
            Log.d("DVIREntryActivity.build_form: ", ex.toString());
        }
    }

    /* We will build the checklist form that will be used.  This section is used if the DVIR
    was partially completed and they want to continue
 */
    private void build_partial_form() {
        try {
            TISDBHelper oDB = new TISDBHelper(getApplicationContext(), sDBName,
                    null, iVersionVal);
            try {
                oDB.createDataBase();
            } catch (IOException ioe) {
                DBLogs.insert("Error: " + ioe.toString(),
                        "DVIREntryActivity.build_form", getApplicationContext(),
                        sDBName, iVersionVal);
                throw new Error("Unable to create database");
            }

            oDB.openDataBase();

            String sSQL = "select DVIRFields._id, DVIRFields.Title, DVIRFieldValues.Value " +
                    "from DVIRFields, DVIRFieldValues " +
                    "where DVIRFieldValues.FieldID = DVIRFields._id and DVIRFieldValues.DVIRNo ='" +
                    sUniqueDVIRID + "'";

            fieldsArrayList = oDB.selectRecordsFromDBList(sSQL, null);

            String sSQLSpinner = "select Name from DVIRCodes order by sort_order, name";
            sSpinnerFieldList = oDB.getList(sSQLSpinner, null);
            sSpinnerFieldList.add(0, "Not Checked");
            String sSQLHeader = "select TruckNo, TrailerNo, BeginMileage, Location, Remarks " +
                    "from DVIREntered where DVIRNo = '" + sUniqueDVIRID + "'";
            ArrayList<String> sDVIRHeaderList = oDB.getList(sSQLHeader, null);

            oDB.close();

            //Populate the header of the form
            etTruckNo.setText(sDVIRHeaderList.get(4));
            etTrailerNo.setText(sDVIRHeaderList.get(3));
            etBeginMiles.setText(sDVIRHeaderList.get(2));
            etLocation.setText(sDVIRHeaderList.get(1));
            if (sDVIRHeaderList.get(0).length() > 0) {
                etRemarks.setText(sDVIRHeaderList.get(0));
            }

            svCheckItems.setScrollbarFadingEnabled(false);
            TableLayout tlCheckListItems = (TableLayout) findViewById(R.id.tlCheckItems);

            for (ArrayList<String> sValue : fieldsArrayList) {
                TableRow trCheckItem = new TableRow(this);
                View v = LayoutInflater.from(this).inflate(R.layout.dvir_check_table_row, trCheckItem, false);
                TextView tvItem = (TextView) v.findViewById(R.id.tvCheckItem);
                tvItem.setText(sValue.get(1));
                Spinner spItem = (Spinner) v.findViewById(R.id.spCheckItem);
                ArrayAdapter<String> spinnerArrayAdapter =
                        new ArrayAdapter<String>(this, R.layout.dvir_spinner_item, sSpinnerFieldList);
                spinnerArrayAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
                spItem.setAdapter(spinnerArrayAdapter);
                spItem.setSelection(sSpinnerFieldList.indexOf(sValue.get(2).toString()));
                tlCheckListItems.addView(v);
            }
        } catch (Exception ex) {
            DBLogs.insert("Error: " + ex.toString(),
                    "DVIREntryActivity.build_form", getApplicationContext(),
                    sDBName, iVersionVal);
            Log.d("DVIREntryActivity.build_form: ", ex.toString());
        }
    }

    /*
      The method will first check that all values have been entered.
      If all values have been entered the data will be saved to the database.
      If all values have not been entered the user will be prompted to please enter all values.
     */
    private boolean saveItems(String sSaveType) {
        Boolean bRtnValue = false;
        // Return value will be set to false if something comes back as unchecked
        // If set to false it means that every item has not been updated
        if (sSaveType.toUpperCase().equals("FULL")) {
            //The form should be complete
            bRtnValue = verifyFormEntry(sSaveType);
        } else {
            //Only the header needs to be complete
            bRtnValue = verifyFormEntry(sSaveType);
        }
        // Only do this if form validation came back clean
        // Should be able to write to the database since form has been validated
        DateConvertClass oDateConvertClass = new DateConvertClass();
        oDateConvertClass.oContext = getApplicationContext();
        String sCurrentDateTime = oDateConvertClass.GMTTimestamp();
        // If a unique id already exists there was a partial save before and we must keep the
        // id since there may have been some pictures saved related to it.
        if (sUniqueDVIRID.length() < 3) {
            Long timeStamp = System.currentTimeMillis() / 1000;
            sUniqueDVIRID = sAndroidID + timeStamp.toString();
        } else {
            deleteDVIR();
        }
        TISDBHelper oDB = new TISDBHelper(getApplicationContext(), sDBName,
                null, iVersionVal);
        try {
            oDB.createDataBase();
        } catch (IOException ioe) {
            DBLogs.insert("Error: " + ioe.toString(),
                    "DVIREntryActivity.saveItems", getApplicationContext(),
                    sDBName, iVersionVal);
            throw new Error("Unable to create database");
        }

        oDB.openDataBase();
        if (bRtnValue) {
            try {
                // Insert the DVIREntered Information
                ContentValues oValues = new ContentValues();
                oValues.put("Location", etLocation.getText().toString());
                oValues.put("BeginMileage", etBeginMiles.getText().toString());
                oValues.put("DriverNo", sUserID);
                oValues.put("TruckNo", etTruckNo.getText().toString());
                oValues.put("TrailerNo", etTrailerNo.getText().toString());
                oValues.put("DVIRNO", sUniqueDVIRID);
                oValues.put("DVIRDateTime", sCurrentDateTime);
                if (sSaveType.toUpperCase().equals("FULL")) {
                    oValues.put("CompletedDVIR", "NO");
                } else {
                    oValues.put("CompletedDVIR", "Part");
                }
                if (etRemarks.getText().length() > 0) {
                    oValues.put("Remarks", etRemarks.getText().toString());
                }
                oDB.insertRecordsInDB("DVIREntered", null, oValues);
                //Now Insert the check items in the scroll view
                //Find the table layout for the check list items
                TableLayout tlCheckListItems = (TableLayout) findViewById(R.id.tlCheckItems);
                for (int i = 0; i < tlCheckListItems.getChildCount(); i++) {
                    String sFieldValue = "";
                    TableRow trValues = (TableRow) tlCheckListItems.getChildAt(i);
                    Spinner spCheckResponse = (Spinner) trValues.getChildAt(1);
                    String sCheckResponse = spCheckResponse.getSelectedItem().toString();
                    TextView tvCheckItem = (TextView) trValues.getChildAt(0);
                    String sCheckItem = tvCheckItem.getText().toString();
                    for (ArrayList<String> sValue : fieldsArrayList) {
                        if (sValue.contains(sCheckItem)) {
                            sFieldValue = sValue.get(0);
                        }
                    }
                    //Enter the DVIR check data into the database
                    oValues.clear();
                    oValues.put("FieldID", Integer.parseInt(sFieldValue));
                    oValues.put("Value", sCheckResponse);
                    oValues.put("DVIRNo", sUniqueDVIRID);
                    oDB.insertRecordsInDB("DVIRFieldValues", null, oValues);
                }
            } catch (Exception ex) {
                DBLogs.insert("Error: " + ex.toString(),
                        "DVIREntryActivity.saveItems", getApplicationContext(),
                        sDBName, iVersionVal);
                Log.d("DVIREntryActivity.saveItems: ", ex.toString());
            } finally {
                oDB.close();
            }
        }
        oDB.close();
        return bRtnValue;
    }

    private boolean verifyFormEntry(String sSaveType) {
        boolean bRtnValue = true;
        try {
            if (etTruckNo.getText().length() == 0) {
                bRtnValue = false;
                etTrailerNo.requestFocus();
            }
            if (etTrailerNo.getText().length() == 0) {
                bRtnValue = false;
                etTrailerNo.requestFocus();
            }
            if (etBeginMiles.getText().length() == 0) {
                bRtnValue = false;
                etBeginMiles.requestFocus();
            }
            if (etLocation.getText().length() == 0) {
                bRtnValue = false;
                etLocation.requestFocus();
            }
            // Only do this part if above did not return false and save type is full
            if (bRtnValue && sSaveType.toUpperCase().equals("FULL")) {
                TableLayout tlCheckListItems = (TableLayout) findViewById(R.id.tlCheckItems);

                for (int i = 0; i < tlCheckListItems.getChildCount(); i++) {
                    TableRow trValues = (TableRow) tlCheckListItems.getChildAt(i);
                    Spinner spCheckResponse = (Spinner) trValues.getChildAt(1);
                    String sCheckResponse = spCheckResponse.getSelectedItem().toString();
                    if (sCheckResponse.equals("Not Checked")) {
                        // this means that somehthing in the list has not been updated
                        bRtnValue = false;
                    }
                }
            }
        } catch (Exception ex) {
            bRtnValue = false;
        }
        return bRtnValue;
    }

    private void queueForSync() {
        // queue the message to be sent
        DateConvertClass oDateConvertClass = new DateConvertClass();
        oDateConvertClass.oContext = getApplicationContext();
        String sCurrentDateTime = oDateConvertClass.GMTTimestamp();
        SyncTasks syncTasks = new SyncTasks();
        syncTasks.oContext = getApplicationContext();
        syncTasks.sRecType = "DVIRN";
        syncTasks.sRecID = sUniqueDVIRID;
        syncTasks.sDateTime = sCurrentDateTime;
        syncTasks.sQueued = "0";
        syncTasks.sDateTimeQueued = "";
        syncTasks.sCompleted = "0";
        syncTasks.sDateTimeCompleted = "";
        syncTasks.write();
    }

    private void errorDialogue(String sTitle, String sMessage) {
        TextView title = new TextView(this);
        title.setText(sTitle);
        title.setBackgroundColor(Color.RED);
        title.setPadding(10, 10, 10, 10);
        title.setGravity(Gravity.CENTER);
        title.setTextColor(Color.WHITE);
        title.setTextSize(20);
        new AlertDialog.Builder(this)
                .setCustomTitle(title)
                .setMessage(sMessage)
                .setPositiveButton(getResources().getString(R.string.ok), new DialogInterface.OnClickListener() {
                    public void onClick(DialogInterface dialog, int which) {
                        // Do nothing but close the dialog
                        dialog.dismiss();
                    }
                })
                .show();
    }

    /*
    Need to delete the partially completed DVIR so we can insert the updates.  It is easier to
    just delete and re add the whole thing
     */
    private void deleteDVIR() {
        try {
            TISDBHelper oDB = new TISDBHelper(getApplicationContext(), sDBName, null, iVersionVal);
            try {
                oDB.createDataBase();
            } catch (IOException ioe) {
                throw new Error("Unable to create database");
            }

            oDB.openDataBase();
            String sWhereClause = "DVIRNo='" + sUniqueDVIRID + "' ";
            oDB.deleteRecordInDB("DVIREntered", sWhereClause);
            oDB.deleteRecordInDB("DVIRFieldValues", sWhereClause);
            oDB.close();
        } catch (Exception ex) {

        }
    }

    private boolean checkForPartialDVIR() {
        Boolean bRtnValue = false;
        Context oContext = getApplicationContext();
        TISDBHelper oDB = new TISDBHelper(oContext, sDBName, null, iVersionVal);
        try {
            oDB.createDataBase();
        } catch (IOException ioe) {
            throw new Error("Unable to create database");
        }

        String sSQL = ("select DVIRNo from DVIREntered where CompletedDVIR = 'Part'");
        oDB.openDataBase();
        ArrayList<String> sDVIRRecordsList = oDB.getList(sSQL, null);
        oDB.close();
        if (!sDVIRRecordsList.isEmpty()) {
            sUniqueDVIRID = sDVIRRecordsList.get(0);
            bRtnValue = true;
        }
        return bRtnValue;
    }

    private void saveState(Bundle outState) {
        outState.putString("truckno", etTruckNo.getText().toString());
        outState.putString("trailerno", etTrailerNo.getText().toString());
        outState.putString("beginmiles", etBeginMiles.getText().toString());
        outState.putString("location", etLocation.getText().toString());
        outState.putString("remarks", etRemarks.getText().toString());
        TableLayout tlCheckListItems = (TableLayout) findViewById(R.id.tlCheckItems);
        for (int i = 0; i < tlCheckListItems.getChildCount(); i++) {
            TableRow trValues = (TableRow) tlCheckListItems.getChildAt(i);
            Spinner spCheckResponse = (Spinner) trValues.getChildAt(1);
            String sCheckResponse = spCheckResponse.getSelectedItem().toString();
            TextView tvCheckItem = (TextView) trValues.getChildAt(0);
            String sCheckItem = tvCheckItem.getText().toString();
            outState.putString(String.valueOf(i) + "-item", sCheckItem);
            outState.putString(String.valueOf(i) + "-response", sCheckResponse);
        }
    }

    private void restoreState(Bundle inState) {
        etTruckNo.setText(inState.getString("truckno"));
        inState.remove("truckno");
        etTrailerNo.setText(inState.getString("trailerno"));
        inState.remove("trailerno");
        etBeginMiles.setText(inState.getString("beginmiles"));
        inState.remove("beginmiles");
        etLocation.setText(inState.getString("location"));
        inState.remove("location");
        etRemarks.setText(inState.getString("remarks"));
        inState.remove("remarks");
        svCheckItems.setScrollbarFadingEnabled(false);
        TISDBHelper oDB = new TISDBHelper(getApplicationContext(), sDBName,
                null, iVersionVal);
        try {
            oDB.createDataBase();
        } catch (IOException ioe) {
            DBLogs.insert("Error: " + ioe.toString(),
                    "DVIREntryActivity.build_form", getApplicationContext(),
                    sDBName, iVersionVal);
            throw new Error("Unable to create database");
        }
        oDB.openDataBase();
        String sSQLSpinner = "select Name from DVIRCodes order by sort_order, name";
        sSpinnerFieldList = oDB.getList(sSQLSpinner, null);
        oDB.close();
        sSpinnerFieldList.add(0, "Not Checked");
        TableLayout tlCheckListItems = (TableLayout) findViewById(R.id.tlCheckItems);
        for (int i = 0; i < (inState.size() - 1) / 2; i++) {
            TableRow trCheckItem = new TableRow(this.getApplicationContext());
            View v = LayoutInflater.from(this).inflate(R.layout.dvir_check_table_row, trCheckItem, false);
            TextView tvItem = (TextView) v.findViewById(R.id.tvCheckItem);
            String sCheckItem = inState.getString(String.valueOf(i) + "-item");
            tvItem.setText(sCheckItem);
            Spinner spItem = (Spinner) v.findViewById(R.id.spCheckItem);
            ArrayAdapter<String> spinnerArrayAdapter =
                    new ArrayAdapter<String>(this, R.layout.dvir_spinner_item, sSpinnerFieldList);
            spinnerArrayAdapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
            spItem.setAdapter(spinnerArrayAdapter);
            String sCheckResponse = inState.getString(String.valueOf(i) + "-response");
            spItem.setSelection(sSpinnerFieldList.indexOf(sCheckResponse));
            tlCheckListItems.addView(v);
        }
    }
}
