package com.perfectech.tis.activities;

import android.app.KeyguardManager;
import android.content.Context;
import android.content.Intent;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.os.PowerManager;
import android.support.v7.app.AppCompatActivity;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;

import com.perfectech.tis.DateConvertClass;
import com.perfectech.tis.R;

public class LongOpenJob extends AppCompatActivity {
    String sJobNumber = null;
    String sJobID = null;
    String sJobStatus = null;

    PowerManager oPowerManager;
    PowerManager.WakeLock oWakeLock;
    KeyguardManager oKeyguardManager;
    KeyguardManager.KeyguardLock oKeyguardLock;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        oPowerManager = (PowerManager) getSystemService(Context.POWER_SERVICE);
        oKeyguardManager = (KeyguardManager) getSystemService(Context.KEYGUARD_SERVICE);
        oKeyguardLock = oKeyguardManager.newKeyguardLock("INFO");
        oWakeLock = oPowerManager.newWakeLock(PowerManager.FULL_WAKE_LOCK | PowerManager.ACQUIRE_CAUSES_WAKEUP | PowerManager.ON_AFTER_RELEASE, "INFO");
        oWakeLock.acquire();
        oKeyguardLock.disableKeyguard();

        setContentView(R.layout.activity_long_open_job);
        setFinishOnTouchOutside(false);
        Bundle extras = getIntent().getExtras();
        String sJobDestination = null;
        if (extras != null) {
            sJobNumber = extras.getString("jobNumber");
            sJobDestination = extras.getString("jobDestinationCity");
            sJobID = extras.getString("jobID");
            sJobStatus = extras.getString("jobStatus");
        }
        TextView tvComments = (TextView) findViewById(R.id.tv_longOpenJobDescription);
        tvComments.setText("Job " + sJobNumber + " has a status of " + sJobStatus + " for to long.");
        Button btCancel = (Button) findViewById((R.id.btn_longOpenCancel));
        btCancel.setOnClickListener(new View.OnClickListener() {
            public void onClick(View v) {
                resetJobLongOpen(sJobNumber);
                finish();
            }
        });
        Button btGoToJob = (Button) findViewById(R.id.btn_longOpenJob);
        btGoToJob.setOnClickListener(new View.OnClickListener() {
            public void onClick(View v) {
                resetJobLongOpen(sJobNumber);
                Intent i = new Intent(getApplicationContext(), JobsDetailActivity.class);
                i.putExtra("JobID", sJobID);
                startActivity(i);
                finish();
            }
        });
    }

    @Override
    protected void onPause() {
        super.onPause();

        if (oWakeLock.isHeld())
            oWakeLock.release();
    }

    @Override
    protected void onResume() {
        super.onResume();
        if (oWakeLock.isHeld())
            oWakeLock.release();
    }

    private void resetJobLongOpen(String sJobID) {
        SharedPreferences activeJobs = getApplicationContext().getSharedPreferences("activeJobs", Context.MODE_PRIVATE);
        DateConvertClass oDateConvertClass = new DateConvertClass();
        oDateConvertClass.oContext = getApplicationContext();
        activeJobs.edit().putString(sJobID, oDateConvertClass.GMTTimestamp()).apply();
    }

}
